package net.wanji.web.task;

import com.alibaba.fastjson.JSONObject;
import lombok.extern.slf4j.Slf4j;
import net.wanji.web.common.constant.Constant;
import net.wanji.web.kafka.ConsumerHandler;
import net.wanji.web.kafka.JNMatchResultMiniData;
import net.wanji.web.websocket.WebSocketServer;
import org.apache.commons.lang3.StringUtils;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import java.util.List;
import java.util.Objects;
import java.util.Set;

/**
 * @author duanruiming
 * @date 2023/05/17 16:08
 */
@Component
@Slf4j
public class RealTimeCarTask {

    @Resource
    private ConsumerHandler consumerHandler;

    @Scheduled(fixedRate = 1000)
    public void pushRealTimeCarInfo() {
        try {
            Set<WebSocketServer> events = WebSocketServer.getWebSocketSet(Constant.WEBSOCKET_TOPIC_CAR_TRAIL_INFO);
            for (WebSocketServer socketServer : events) {
                String picLicense = socketServer.getUserId();
                JNMatchResultMiniData jnMatchResultMiniData = consumerHandler.getTopicMessage("CSMatchResultMiniData_0");
                if (Objects.nonNull(jnMatchResultMiniData) ) {
                    List<JNMatchResultMiniData.E1FrameParticipant> list = jnMatchResultMiniData.getE1FrameParticipant();
                    if (!CollectionUtils.isEmpty(list)) {
                        for (JNMatchResultMiniData.E1FrameParticipant e1FrameParticipant : list) {
                            int id = e1FrameParticipant.getId();
                            String license = e1FrameParticipant.getPicLicense();
                            if (3573 == e1FrameParticipant.getId() ||  StringUtils.equals(license, picLicense)) {
                                socketServer.sendMessage(JSONObject.toJSONString(e1FrameParticipant));
                            }
                        }
                    }
                }
            }
        } catch (Exception e) {
            log.error("通过车牌推送数据失败，异常信息", e);
        }
    }

}
